pub struct InteractivePolicy;Expand description
Interactive policy - always ask the user.
This is the default policy used by the TUI. All permission requests are forwarded to the consumer for user decision.
Example
ⓘ
use agent_core_runtime::agent::interface::InteractivePolicy;
let policy = InteractivePolicy;
// All permission requests will prompt the userImplementations