Common utilities shared across providers. Common utilities shared across LLM providers.
Functions
- escape_
json_ string - Escapes special characters for JSON string values.
- extract_
text_ content - Extract text content from a message, joining multiple text blocks with newlines.
- generate_
unique_ id - Generate a unique ID for tool calls. Uses an atomic counter combined with timestamp for uniqueness across restarts.