pub struct SkillDiscovery { /* private fields */ }Expand description
Discovers skills from configured directories.
Implementations
Sourceimpl SkillDiscovery
impl SkillDiscovery
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new skill discovery instance with default search paths.
Default paths:
$PWD/.skills/- Project-local skills~/.agent-core/skills/- User skills
Sourcepub fn search_paths(&self) -> &[PathBuf]
pub fn search_paths(&self) -> &[PathBuf]
Get the configured search paths.
Sourcepub fn discover(&self) -> Vec<Result<Skill, SkillDiscoveryError>>
pub fn discover(&self) -> Vec<Result<Skill, SkillDiscoveryError>>
Discover all skills from configured directories.
Returns a vector of results, one for each skill found or error encountered. Each immediate subdirectory containing a SKILL.md file is treated as a skill.
Sourcepub fn discover_valid(&self) -> Vec<Skill>
pub fn discover_valid(&self) -> Vec<Skill>
Discover skills and collect only the successful ones.
Errors are silently ignored. Use discover() if you need error information.